<?php

class BSPBPayment extends payment
{
    public function validate()
    {
        return true;
    }

    public function process($template = null)
    {
        $this->order->order();

        $xml = new \SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><TKKPG></TKKPG>');
        $xmlRequest = $xml->addChild('Request');
        $xmlRequest->addChild('Operation', 'CreateOrder');
        $xmlRequest->addChild('Language', $this->collectionValue($this->object->bspb_language, 'language'));
        $xmlOrder = $xmlRequest->addChild('Order');
        $xmlOrder->addChild('OrderType', $this->collectionValue($this->object->bspb_order_type, 'order-type'));
        $xmlOrder->addChild('Merchant', $this->object->bspb_merchant);
        $xmlOrder->addChild('Amount', ((float)$this->order->getActualPrice() * 100));
        $xmlOrder->addChild('Currency', $this->collectionValue($this->object->bspb_currency, 'currency'));
        $xmlOrder->addChild('Description', $this->object->bspb_description);

        $resultUrl = 'https://' . cmsController::getInstance()->getCurrentDomain()->getHost() . '/emarket/gateway/' . $this->order->getId();
        $xmlOrder->addChild('ApproveURL', $resultUrl);
        $xmlOrder->addChild('CancelURL', $resultUrl);
        $xmlOrder->addChild('DeclineURL', $resultUrl);
        
        $xmlAddParams = $xmlOrder->addChild('AddParams');
        $xmlAddParams->addChild('ShopOrderNum', $this->order->getId());

        $strResponse = $this->sendPostXml($this->getPayUrl(), $xml->asXML(), $this->object->bspb_cert1, $this->object->bspb_cert2);
        if (is_array($strResponse) && strlen($strResponse['error']) == 0) {
            $response = $this->XmlToArray($strResponse['data']);
            if ($response['Response']['Status'] == '00') {
                $params = array();
                $params['url'] = $response['Response']['Order']['URL'];
                $params['orderid'] = $response['Response']['Order']['OrderID'];
                $params['sessionid'] = $response['Response']['Order']['SessionID'];
                $this->order->setPaymentStatus('initialized');
                list($form_block) = def_module::loadTemplates('emarket/payment/expresspay/' . $template, 'form_block');
                return def_module::parseTemplate($form_block, $params);
            }
        }

        throw new publicException(getLabel('error-payment-wrong-settings'));
    }

    public function poll()
    {
        $data = $this->XmlToArray(getRequest('xmlmsg'));
        if (array_key_exists('Message', $data)) {
            $orderId = $data['Message']['OrderID'];
            $sessionId = $data['Message']['SessionID'];
        } else {
            $orderId = $data['OrderID'];
            $sessionId = $data['SessionId'];
        }

        $xml = new \SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><TKKPG></TKKPG>');
        $xmlRequest = $xml->addChild('Request');
        $xmlRequest->addChild('Operation', 'GetOrderInformation');
        $xmlRequest->addChild('Language', $this->collectionValue($this->object->bspb_language, 'language'));
        $xmlOrder = $xmlRequest->addChild('Order');
        $xmlOrder->addChild('Merchant', $this->object->bspb_merchant);
        $xmlOrder->addChild('OrderID', $orderId);
        $xmlRequest->addChild('SessionID', $sessionId);
        $xmlRequest->addChild('ShowParams', 'true');
        $xmlRequest->addChild('ShowOperations', 'true');
        $xmlRequest->addChild('ClassicView', 'true');

        $isSuccess = false;
        $host = 'https://' . cmsController::getInstance()->getCurrentDomain()->getHost();
        $strResponse = $this->sendPostXml($this->getPayUrl(), $xml->asXML(), $this->object->bspb_cert1, $this->object->bspb_cert2);
        if (is_array($strResponse) && strlen($strResponse['error']) == 0) {
            $dataInit = $this->XmlToArray($strResponse['data']);
            if ($dataInit && $dataInit['Response']['Status'] == '00') {
                if ($dataInit['Response']['Order']['row']['Orderstatus'] == 'APPROVED') {
                    $isSuccess = true;
                    $this->order->setPaymentStatus('accepted');
                    $host .= '/emarket/purchase/result/successful/';
                }
            }
        }

        if (!$isSuccess) {
            $this->order->setPaymentStatus('declined');
            $host .= '/emarket/purchase/result/fail/';
        }

        $this->order->commit();

        $cmsController = cmsController::getInstance();
        $module = $cmsController->getModule("emarket");
        if ($module) {
            $module->redirect($host);
        }
    }

    private function getPayUrl()
    {
        if ($this->object->bspb_test) {
            return 'https://mpitest.bspb.ru:5443/Exec';
        } else {
            return 'https://mpi.bspb.ru:5443/Exec';
        }
    }

    private function sendPostXml($url, $xml, $pathCertPem, $pathCertKey)
    {
        $path = $_SERVER['DOCUMENT_ROOT'] . '/.cert/';
        
        $error = '';
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSLCERT, $path.$pathCertPem);
        curl_setopt($ch, CURLOPT_SSLKEY, $path.$pathCertKey);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_VERBOSE, 1);
        if (!$answer = curl_exec($ch)) {
            $error = 'Error with connection: ' . curl_errno($ch);
        }
        curl_close($ch);

        return array(
            'data' => $answer,
            'error' => $error
        );
    }

    private function XmlToArray($strXml)
    {
        $strXml = str_replace("\\\"", "'", $strXml);
        $json = json_encode(simplexml_load_string($strXml));
        return json_decode($json, true);
    }

    private function findOrderId($arr)
    {
        foreach($arr as $val)
            if (is_array($val) && key_exists('PARAMNAME',$val) && key_exists('VAL',$val) && $val['PARAMNAME'] == 'ShopOrderNum')
                return $val['VAL'];
        return -1;
    }

    private function collectionValue($objectId, $type)
    {
        $objectsCollection = umiObjectsCollection::getInstance();
        $object = $objectsCollection->getObject($objectId);
        $name = $object->getName();
        if ($type == 'order-type') {
            $option = array(
                'Purchase' => 'Purchase',
                'Payments' => 'Payments'
            );
        } elseif ($type == 'currency') {
            $option = array(
                'рубли' => '643'
            );
        } elseif ($type == 'language') {
            $option = array(
                'русский' => 'RU',
                'английский' => 'EN'
            );
        }
        return $option[$name];
    }
}
