<?php

$className = 'BSPB';
$paymentName = 'Оплата картой (BSPB)';

include 'standalone.php';

$objectTypesCollection = umiObjectTypesCollection::getInstance();
$objectsCollection = umiObjectsCollection::getInstance();

// получаем родительский тип
$parentTypeId = $objectTypesCollection->getTypeIdByGUID("emarket-payment");

// Тип для внутреннего объекта, связанного с публичным типом
$internalTypeId = $objectTypesCollection->getTypeIdByGUID("emarket-paymenttype");
$typeId = $objectTypesCollection->addType($parentTypeId, $paymentName);
$objectType = $objectTypesCollection->getType($typeId);

$groupdId = $objectType->addFieldsGroup('settings', 'Параметры', true, true);
$group = $objectType->getFieldsGroupByName('settings');

$fieldsCollection = umiFieldsCollection::getInstance();

$fieldTypesCollection = umiFieldTypesCollection::getInstance();
$typeBoolean = $fieldTypesCollection->getFieldTypeByDataType('boolean')->getId();
$typeString = $fieldTypesCollection->getFieldTypeByDataType('string')->getId();
$typeInt = $fieldTypesCollection->getFieldTypeByDataType('int')->getId();
$typeSelect = $fieldTypesCollection->getFieldTypeByDataType('relation')->getId();

$optionOrderTypeValue = $objectTypesCollection->addType(1, 'bspb-order-type');
$optionOrderType = array(
    'Purchase' => 'Purchase',
    'Payments' => 'Payments'
);
foreach ($optionOrderType as $key => $value) {
    $objectsCollection->addObject($value, $optionOrderTypeValue);
}

$optionCurrencyValue = $objectTypesCollection->addType(1, 'bspb-currency');
$optionCurrency = array(
    '643' => 'рубли'
);
foreach ($optionCurrency as $key => $value) {
    $objectsCollection->addObject($value, $optionCurrencyValue);
}

$optionLanguageValue = $objectTypesCollection->addType(1, 'bspb-language');
$optionLanguage = array(
    'RU' => 'русский',
    'EN' => 'английский'
);
foreach ($optionLanguage as $key => $value) {
    $objectsCollection->addObject($value, $optionLanguageValue);
}

$fields = array(
    'bspb_test' => array(
        'name' => 'Тест режим',
        'tip' => 'В этом режиме плата за товар не снимается',
        'type' => $typeBoolean,
        'required' => true,
    ),
    'bspb_merchant' => array(
        'name' => 'Merchant',
        'tip' => 'Идентификатор магазина, который выдается банком',
        'type' => $typeString,
        'required' => true,
    ),
    'bspb_cert1' => array(
        'name' => 'Имя файл *.pem',
        'tip' => 'Файл должен лежать в папке /.cert/',
        'type' => $typeString,
        'required' => true,
    ),
    'bspb_cert2' => array(
        'name' => 'Имя файл *.key',
        'tip' => 'Файл должен лежать в папке /.cert/',
        'type' => $typeString,
        'required' => true,
    ),
    'bspb_order_type' => array(
        'name' => 'Тип транзакции',
        'type' => $typeSelect,
        'guide_id' => $optionOrderTypeValue,
        'required' => true,
    ),
    'bspb_currency' => array(
        'name' => 'Валюта платежа',
        'type' => $typeSelect,
        'guide_id' => $optionCurrencyValue,
        'required' => true,
    ),
    'bspb_description' => array(
        'name' => 'Описание заказа для банка',
        'tip' => 'Обязательный параметр',
        'type' => $typeString,
        'required' => true,
    ),
    'bspb_language' => array(
        'name' => 'Язык интерфейса',
        'type' => $typeSelect,
        'guide_id' => $optionLanguageValue,
        'required' => true,
    ),
);

foreach ($fields as $code => $arField) {
    $fieldId = $fieldsCollection->addField($code, $arField['name'], $arField['type']);
    $field = $fieldsCollection->getField($fieldId);

    $isRequired = isset($arField['required']) ? $arField['required'] : false;
    if (isset($arField['guide_id'])) {
        $field->setGuideId($arField['guide_id']);
    }
    $field->setIsRequired($isRequired);
    $field->setIsInSearch(false);
    $field->setIsInFilter(false);
    $field->commit();

    $group->attachField($fieldId);
}

// Создаем внутренний объект
$internalObjectId = $objectsCollection->addObject($paymentName, $internalTypeId);
$internalObject = $objectsCollection->getObject($internalObjectId);
$internalObject->setValue('class_name', $className); // имя класса для реализации

// связываем его с типом
$internalObject->setValue('payment_type_id', $typeId);
$internalObject->setValue('payment_type_guid', 'emarket-payment-' . $typeId);
$internalObject->commit();

// Связываем внешний тип и внутренний объект
$type = $objectTypesCollection->getType($typeId);
$type->setGUID($internalObject->getValue('payment_type_guid'));
$type->commit();

echo "Готово!";
unlink(__FILE__);
